Stan Math Library: stan/math/rev/scal/fun/square.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

square.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_SQUARE_HPP
2 #define STAN_MATH_REV_SCAL_FUN_SQUARE_HPP
3
4 #include <stan/math/rev/core.hpp>
5
6 namespace stan {
7 namespace math {
8
9 namespace {
10 class square_vari : public op_v_vari {
11 public:
12 explicit square_vari(vari* avi) :
13 op_v_vari(avi->val_ * avi->val_, avi) {
14 }
15 void chain() {
16 avi_->adj_ += adj_ * 2.0 * avi_->val_;
17 }
18 };
19 }
20
46 inline var square(const var& x) {
47 return var(new square_vari(x.vi_));
48 }
49
50 }
51 }
52 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::square
fvar< T > square(const fvar< T > &x)
Definition: square.hpp:15
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43

[ Stan Home Page ] © 2011–2016, Stan Development Team.